=====================================================
超名的研究方向再探
=====================================================

.. Further exploration of My Personal Research Direction



人类认知的屏障
=================

世界是可知的吗？
------------------

前段时间一直想做一些认知科学，比如认知神经科学的学习。这种学科跟计算机科学的研究很不一
样。计算机科学本质上属于工程学科，工程学科的根本目的在于创造，创造出没有的东西来，能用，
能玩。但是认知科学这种基础科学却不一样。它的本质目的是为了发现，发现这个世界的规律，发现
这个世界的法则，发现我们的未知。所以，做这样的科学的研究，首先要想明白的一件事情是，你
去发现的这些规律，发现的这些法则，是真实的世界的样子吗？倒并不是担心“今天你发现一个定理
，明天你就爬起床发现没有考虑到反面情况，然后开始推翻这个定理”的这种状况，而是像深度学习
那样，它是在以一种人类大脑不可能考虑（甚至不可能理解）的“思维”方式在运作。（这只是我的
一种妥协的假设！！非共识。）也就是说，不是时间问题，不是今天没认识到后天也能发现的问题，
而是大脑本质架构、大脑自身局限就决定了，根本就不可能认识到。比如，人类眼睛的架构就决定了
我们不能理解活在可见光以外的动物所看到的的世界；我们三维的大脑就决定了四维甚至五维以上的
时空的视界是无法感受的；同样，我们也就只能通过原子碰撞来“粗略”认识下看不见的原子、分子、
电子、中微子；而至于暗物质、暗能量嘛，我们甚至都不知道它们在那里。那么，我们要怎么认知它
们？其实，这些都只是我们知道的我们不知道的事物，还有更多我们甚至都不知道我们不知道的事物。
所以，我们怎么做研究？我们怎么能够说，我们就认识到了、发现了，这个世界的规律，这个世界的
本质？我们已有的这些研究、规律、定理、理论，是否只是适合于我们所处的这个世界的研究、规律、
定理、理论？我们是否只是侧着一只眼、只是用一个视角来理解这个宇宙，这个世界？我们感受到的
这一切，费心费力作出努力的找出来的这些伟大的理论，是否就只是一种偏见？

明白了这个问题，我们或许就会明白，为什么有些哲学家会感觉到绝望。比如，休谟 [1]_ 就发现，人们通
常叫做“外物”的东西，实质上只不过是自己的知觉，即印象和观念。

::

	除了人心的知觉或印象和观点以外，没有任何东西真正存在于人心之中，而且外物只是借它们所引起
	的那些知觉才被认识的。
	
	—— 《人性论》休谟


休谟的哲学思考常常把自己“置于那样绝望和孤寂的境地”，使他感觉到“惊慌和迷乱”。他本不应该
走到极端。他的哲学让他开始怀疑一切，怀疑生活中的所有，比如，狗真的是四条腿吗？这只猫真的是
存在的吗？三角形真的只有三个角吗？因此在实际生活中，他不得不忘掉自己的哲学，“拿定主意要生
活、谈话、行事，像过普通生活的他人一样。” [1]_

注：所有具备这种思想的哲学家，都是自由意志、自我意识太过强烈的人。试想一个农民天晴了就赶快
出来晒自家稻谷，下雨了就赶紧收。他老是被动地接受这一切，怎么能认识到他所经历的这些都是假的？
人类的自由意志如此之强，很难让人相信精神只是物质在大脑中的一种反映。


马克主义哲学回答基本问题的局限性
--------------------------------

上述问题的本质是哲学的一个基本问题：这个世界是可知的吗？马克思主义哲学把这个问题考察得比
较全面，但是在我一个外行看来，还是觉得存在着一定的局限。

马克思主义哲学实质是关于思维和存在，物质和精神的世界观、方法论（？）。马克思主义哲学批判了
三种世界观——客观唯心主义、主观唯心主义、主观唯物主义，支持一种——辩证唯物主义。（我们总
称为唯物主义和唯心主义，至于主观与客观这两个前缀，是关于认识论问题上的区别，不是世界观上的，
暂不讨论）唯物主义认为，世界上什么也没有，除了物质；而精神呢，只不过是物质现象在头脑中的一种
反映。唯心主义则认为，世界上也是什么都没有，但除了精神；而至于物质嘛，不过是精神的产物。有没
有第三种世界观呢——既存在物质，又存在精神？有。马克思主义哲学（马哲）称它为二元论。但马哲
认为二元论不可能坚持到底，因为它必须又设想一个凌驾于思维和物质两者之上的一个中立的本体，称
为“要素”、“原则同格”……但是所谓的“要素”等，在马哲看来，也只不过是唯心论中感觉等的
别名罢了。偷换概念。有了这个基础命题之后，马哲认为，\textbf{世界上没有什么原则上不可能被认
识的东西，只有现在还没有被认识的东西}。 即，这个世界，是可知的。

另外，马哲高明的地方，不仅仅是说一个观点，简单地宣布唯心论是胡说，他还研究了为什么唯心论是
胡说，指出是通过认识过程中的什么环节、什么途径才得出唯心论的这种结论。

* 社会阶级根源：统治阶级需要利用谎言和伪善来欺骗被统治阶级，唯心论因此成为他们的思想武器，如
  在中世纪等无产阶级登上历史舞台以前的时期，神、上帝意志等的唯心论调。
* 认识论根源：1、意识是客观世界的主观映像，是被移植于人脑中并在人脑中被改造过的物质现象。意识
  的内容和源泉是客观的，意识的形式是主观。这就存在一种可能，即当人们在考察意识现象的时候，只
  看到了主观的方面，忽略了客观的方面；只看到意识的形式，没有看到意识的内容和源泉；
  只看到映像，没有看到映像所反映的客观物质世界。哲学史表明，当人们把认识的一个成分——感觉——夸大
  为脱离物质的绝对的东西时，就陷入所谓的“纯粹的经验论”，即主观唯心主义（贝克莱、马赫）。当
  人们把认识过程中的另一个成分——概念——夸大为脱离物质的绝对存在时，就陷入客观唯心论（柏拉
  图，黑格尔）。2、意识对客观世界的反映不是消极的、被动的，而是积极地、能动的；人不仅能认识
  世界，还能通过认识改造世界。但是，如果把意识的能动作用夸大到不受客观世界制约的程度，否定了
  意识是存在的反映，就陷入了唯心论。

但是马哲的思考引起了如下一些问题，现在的 神经科学、认知科学和哲学、心理学，回答不了如下问题：

* **意识到底是什么？**如果意识是物质的一种映像，那这种映像是什么？它的表现形式是什么样的？
  它是另一种物质吗？还是说，精神（即意识）与物质是对立的——正如千百年来哲学所探索得那样？
* 意识是物质的一种映像，那，物质 到 映像， 这两者之间转换的桥梁是什么？物质、客观世界是如
  何变成映像、变成意识的？**媒介、过程，到底是什么？它是物质的，还是精神的？**
* **意识是否能够认识意识？意识自身的认知是否可行？**如果意识是一种物质，那么意识对于意识
  的认知有了一定的可能性，但是，那么哲学的争论是否是一种玩笑？唯心论、唯物论是否都是错的？
  另外，如果意识不是一种物质，那么，意识自身的认知的可能性有多大？是否就缺乏了认知的基础了？
* 另外，诚然意识的主观能动性不能超越客观世界的限制，但是，**意识自己控制意识**，是怎么回事
  儿？比如，我时刻知道自己的意识一直很清楚地明白自己的意识都跑到哪儿去了。

Notes
-----
注：所有论述马哲、休谟等内容，都来自于《唯物辩证法大纲》（李达 主编）[2]_ 一书。


脑器官的逆袭
=============

现在，阐述我的观点如下。

首先，智力是什么？什么是智力？智力的原初意义，在于帮助人类生存。远古时代，东非大草原上，
人类为了生存，为了更好地对环境进行感知，进化出了较大的大脑、弯曲褶皱的大脑皮层等特征。远
古人类的这些新的特征，与其他的物种相比较，有更多的优势。比如，对于听觉、视觉、声觉等信息的
处理，虽然感知范围或感知速度没有多少提升，但是，这些通过简单感觉器官映射产生的简单信息，传
到了一个较大的大脑，一个更复杂的大脑，得到了更多、更复杂的处理。于是，人类大脑相较于其他动
物的大脑，不仅具备了对周边环境的感知，还具备了对这些感知信息的记忆；不仅具备了感知信息的短
期记忆，还具备不可思议的长期记忆。更重要的是，复杂的大脑，让人类对于这种即时信息的处理，有
了更丰富、更完备、更智慧的决策判断。因此，相较于其它动物，人类才能更好地躲避天敌，更好地获
得食物，更好地利用工具。生存，也就容易得多。

然而，更大的大脑，更丰富的脑结构，更广阔的大脑皮层，带来不仅仅是面对即时情境下快捷、完备、
智慧的决策判断能力，更重要的是，当有了美妙的、恰到好处的记忆之后，联想、抽象、想象、推理等
高级脑认知功能也因此而产生。人类具备了对过去情境的反思、总结能力，具备了对未来情境的预测、
想象能力。如果说即时情境下的判断能力能帮助人类这个物种能够持续长久地生存下来，那么，对于过
去、未来情境的处理，能够帮助人类生存得更好。

能够持续生存，还能生存得更好，远古人类于是开始建立文明。在文明内部，社会的职能分工开始顺其
自然、必不可少地产生了。一个以务农为生的人，他修好了自己的犁。邻居也来找他修补。为了回报他
的工作，答应给他些钱。之后，第三，第四个人也相继来了。于是，铁匠便开始诞生。另一个人，对自
己的子女教导有方，邻居便把自己的孩子交给他，其他人也来了，于是教师便产生了。 [3] 各种各样
的社会分工就这样开始诞生了。其中最大的趋势就是，体力劳动与脑力劳动越来越独立。越来越多的人
开始从生存斗争中解放出来，将越来越多的时间放在精神的探寻与大脑的运作上。从此，人类开始创造
出了美妙绝伦、无可比拟、前所未有的，丰富、庞大、甚至恐怖的精神财富。在这个惊天地泣鬼神的过
程中，最大的因素便是，上帝为了让人类更易生存而无意之间创造出来的这样一个大脑，没想到，有如
此巨大的潜力。我们不知道我们的大脑还可以这样运作，我们不知道我们的大脑运作得如此有效。我们
的大脑不仅懂得创造，还懂得站在已有的创造之上做出更美妙的创造。我们的大脑不仅有效，还能够通
过训练、指导，使它变得更加有效。这就是变革！我们从肉体中解放出来大脑来。开始将**大脑这个原
本属于辅助物、原本属于陪衬品、原本为了胃器官和性器官等而存在的“部件”，变成真正的，目的、
意义、价值**。

人类认知基础（大脑）存在巨大局限
=====================================

大脑的逆袭史告诉我们，人的脑袋，终究是一颗肉脑袋。它存在着太多的局限性。大脑并不是一个理想
的结构。另外，人的大脑，寄存在我们的肉身里面，我们肉身，已经严重阻碍了大脑的发展。

在《心灵的未来》 [3]_ 一书中，加来道雄如是写道：

::

	400年前，望远镜发明了，几乎一夜之间，这个新颖的、神奇的工具窥见了天体的心脏。这是自古以
	来一个最具革命性的（和煽动性的）仪器。突然，你能亲眼看到过去的神话和教条如同早晨的云雾
	蒸发了。月亮并不像神的智慧说的那样完美而是有锯齿状的火山口，太阳有黑色的斑点，木星有卫
	星，金星有相，土星有环。在望远镜发明后15年所学到的东西比人类历史的总和还多。
	
	像望远镜的发明一样，在20世纪90年代和21世纪，磁共振成像（MRI）机和各种先进的脑部扫描器的
	引进改变了神经科学。我们在过去15年对大脑的了解比之前所有的人类历史所了解的更多，并且心
	灵，一度被认为是遥不可及的，终于呈现在舞台的中心。

人类的心智、智力、灵魂，寄存在我们的肉身内，但是肉身的局限，让人类根本接触不到这个世界的真相。
我们对这个世界的认知已经严重受制于肉身的局限。量子物理学是最激动人心的科学领域。这个领域几百年
来吸引着全球最聪明的大脑来进行攻克世界难题。但是，细细想来，我们对于亚原子粒子的研究，其实也不
过是通过大型强子对撞机的原子碰撞的产物分析，从一个间接的侧面来认知亚原子粒子的性质。我们的量子
理论如此玄妙莫测，只不过是因为我们宏观的肉身无法生活在微观世界中，完全无法感受亚原子粒子的世界，
只不过通过一些理论来间接又缓慢地认识罢了。

当我们生病，我们的大脑几乎很难工作。当我们坐在车上，看见车窗外的快速闪过的近景，会有些微的不适
应，而当我们看着远方慢速掠过的物体时，却没有丝毫的不舒服。

不仅如此，人类的认知同时也受制于我们的大脑的局限。人类站在远处看一个物体，只能看见大概轮廓、全
貌，在近处，我们才能看见细节。但是，远处的物体，原本就是由这些细节构成的，按道理来说，站在远处，
我们看到的东西应该更多才对。但是没有，我们站在远处看物体，看到了全貌，却丢失了细节。人类的资源
带宽是有限的，我们的大脑不允许处理如此丰富的细节，只能做简化。这就是大脑认知的局限所在。


与机器赛跑
===========

在这个时代，我们已经不再是与同龄人赛跑了，我们一直是在跟机器赛跑，在跟时代赛跑。无论是蒸汽机的
出现，还是计算机的出现，都让人类的很多能力在逐渐被替代。前者替代了我们的体力劳动，后者不仅替代
体力劳动能力，目前正在替代我们的脑力劳作能力。

特别是在现在，人工智能的兴起，让全球对AI对人类的替代感到了深深的恐惧。无论怎样，当人工智能发展
到了一定阶段之后，人与机器的“战争”势在必行。AI的崛起，让我们对人类的认知、大脑感到了深深的怀
疑。我们会越来越强烈地渴求人类大脑极限的突破。我们对自身的认知方式，急需一种变革。比如，对于学
习，对于记忆。

突破屏障
==========

的确，无论我们的大脑如果突破这个肉身的屏障，我们还是寄存在一定的结构基础上。但是，相比寄存于肉
身，寄居于机械物质的认知相对来说更知道前进的方向。我们的肉身大脑，就算我们知道我们存在着局限，
却不知道如何才能改进；就算能改进，也不可能通过基因技术达到数量级意义上的提升。


身心分离，是人类的认知的终极方向
====================================


``2017-1-21`` -- ``2017-2-21``


.. [1] Hume, David. A treatise of human nature. Courier Corporation, 2003.
.. [2] 李达. "唯物辩证法大纲." (1978).
.. [3] Kaku, Michio. The future of the mind: The scientific quest to understand, enhance, and empower the mind. Doubleday, 2014.



